@@ -18,31 +18,33 @@
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "dockcorona.h"
+// local
 #include "config-latte.h"
-#include "importer.h"
-#include "../liblattedock/dock.h"
+#include "lattecorona.h"
+#include "layouts/importer.h"
+#include "../liblatte2/types.h"
 
+// C++
 #include <memory>
 #include <csignal>
 
+// Qt
 #include <QApplication>
 #include <QDebug>
 #include <QQuickWindow>
 #include <QCommandLineParser>
 #include <QCommandLineOption>
-#include <QDebug>
 #include <QDir>
 #include <QLockFile>
 #include <QSharedMemory>
 
+// KDE
 #include <KCrash>
 #include <KLocalizedString>
 #include <KAboutData>
 #include <KDBusService>
 #include <KQuickAddons/QtQuickSettings>
 
-
 //! COLORS
 #define CNORMAL  "\e[0m"
 #define CIGREEN  "\e[1;32m"
@@ -98,6 +100,7 @@ int main(int argc, char **argv)
     parser.addOptions({
         {{"r", "replace"}, i18nc("command line", "Replace the current Latte instance.")}
         , {{"d", "debug"}, i18nc("command line", "Show the debugging messages on stdout.")}
+        , {{"cc", "clear-cache"}, i18nc("command line", "Clear qml cache. It can be useful after system upgrades.")}
         , {"default-layout", i18nc("command line", "Import and load default layout on startup.")}
         , {"available-layouts", i18nc("command line", "Print available layouts")}
         , {"layout", i18nc("command line", "Load specific layout on startup."), i18nc("command line: load", "layout_name")}
@@ -141,13 +144,14 @@ int main(int argc, char **argv)
 
     parser.process(app);
 
+    //! print available-layouts
     if (parser.isSet(QStringLiteral("available-layouts"))) {
-        QStringList layouts = Latte::Importer::availableLayouts();
+        QStringList layouts = Latte::Layouts::Importer::availableLayouts();
 
         if (layouts.count() > 0) {
             qInfo() << i18n("Available layouts that can be used to start Latte:");
 
-            foreach (auto layout, layouts) {
+            for (const auto &layout : layouts) {
                 qInfo() << "     " << layout;
             }
         } else {
@@ -162,18 +166,20 @@ int main(int argc, char **argv)
     int memoryUsage = -1;
     QString layoutNameOnStartup = "";
 
+    //! --default-layout option
     if (parser.isSet(QStringLiteral("default-layout"))) {
         defaultLayoutOnStartup = true;
     } else if (parser.isSet(QStringLiteral("layout"))) {
         layoutNameOnStartup = parser.value(QStringLiteral("layout"));
 
-        if (!Latte::Importer::layoutExists(layoutNameOnStartup)) {
-            qInfo() << i18nc("layout missing", "This layout doesnt exist in the system.");
+        if (!Latte::Layouts::Importer::layoutExists(layoutNameOnStartup)) {
+            qInfo() << i18nc("layout missing", "This layout doesn't exist in the system.");
             qGuiApp->exit();
             return 0;
         }
     }
 
+    //! --replace option
     QString username = qgetenv("USER");
 
     if (username.isEmpty())
@@ -198,8 +204,19 @@ int main(int argc, char **argv)
         return 0;
     }
 
+    //! clear-cache option
+    if (parser.isSet(QStringLiteral("clear-cache"))) {
+        QDir cacheDir(QDir::homePath() + "/.cache/lattedock/qmlcache");
+
+        if (cacheDir.exists()) {
+            cacheDir.removeRecursively();
+            qDebug() << "Cache directory found and cleared...";
+        }
+    }
+
+    //! import-full option
     if (parser.isSet(QStringLiteral("import-full"))) {
-        bool imported = Latte::Importer::importHelper(parser.value(QStringLiteral("import-full")));
+        bool imported = Latte::Layouts::Importer::importHelper(parser.value(QStringLiteral("import-full")));
 
         if (!imported) {
             qInfo() << i18n("The configuration cannot be imported");
@@ -208,8 +225,9 @@ int main(int argc, char **argv)
         }
     }
 
+    //! import-layout option
     if (parser.isSet(QStringLiteral("import-layout"))) {
-        QString importedLayout = Latte::Importer::importLayoutHelper(parser.value(QStringLiteral("import-layout")));
+        QString importedLayout = Latte::Layouts::Importer::importLayoutHelper(parser.value(QStringLiteral("import-layout")));
 
         if (importedLayout.isEmpty()) {
             qInfo() << i18n("The layout cannot be imported");
@@ -220,12 +238,14 @@ int main(int argc, char **argv)
         }
     }
 
+    //! memory usage option
     if (parser.isSet(QStringLiteral("multiple"))) {
-        memoryUsage = (int)(Latte::Dock::MultipleLayouts);
+        memoryUsage = (int)(Latte::Types::MultipleLayouts);
     } else if (parser.isSet(QStringLiteral("single"))) {
-        memoryUsage = (int)(Latte::Dock::SingleLayout);
+        memoryUsage = (int)(Latte::Types::SingleLayout);
     }
 
+    //! debug/mask options
     if (parser.isSet(QStringLiteral("debug")) || parser.isSet(QStringLiteral("mask"))) {
         //! set pattern for debug messages
         //! [%{type}] [%{function}:%{line}] - %{message} [%{backtrace}]
@@ -254,7 +274,7 @@ int main(int argc, char **argv)
     KCrash::setDrKonqiEnabled(true);
     KCrash::setFlags(KCrash::AutoRestart | KCrash::AlwaysDirectly);
 
-    Latte::DockCorona corona(defaultLayoutOnStartup, layoutNameOnStartup, memoryUsage);
+    Latte::Corona corona(defaultLayoutOnStartup, layoutNameOnStartup, memoryUsage);
     KDBusService service(KDBusService::Unique);
 
     return app.exec();
@@ -273,7 +293,6 @@ inline void configureAboutData()
                      , QStringLiteral("\251 2016-2017 Michail Vourlakos, Smith AR"));
 
     about.setHomepage(WEBSITE);
-    about.setBugAddress(BUG_ADDRESS);
     about.setProgramLogo(QIcon::fromTheme(QStringLiteral("latte-dock")));
     about.setDesktopFileName(QStringLiteral("latte-dock"));
 
