@@ -655,6 +655,37 @@ void View::setLatteTasksArePresent(bool present)
     emit latteTasksArePresentChanged();
 }
 
+bool View::isTouchingBottomViewAndIsBusy() const
+{
+    return m_isTouchingBottomViewAndIsBusy;
+}
+
+void View::setIsTouchingBottomViewAndIsBusy(bool touchAndBusy)
+{
+    if (m_isTouchingBottomViewAndIsBusy == touchAndBusy) {
+        return;
+    }
+
+    m_isTouchingBottomViewAndIsBusy = touchAndBusy;
+
+    emit isTouchingBottomViewAndIsBusyChanged();
+}
+
+bool View::isTouchingTopViewAndIsBusy() const
+{
+    return m_isTouchingTopViewAndIsBusy;
+}
+
+void View::setIsTouchingTopViewAndIsBusy(bool touchAndBusy)
+{
+    if (m_isTouchingTopViewAndIsBusy == touchAndBusy) {
+        return;
+    }
+
+    m_isTouchingTopViewAndIsBusy = touchAndBusy;
+    emit isTouchingTopViewAndIsBusyChanged();
+}
+
 void View::preferredViewForShortcutsChangedSlot(Latte::View *view)
 {
     if (view != this) {
