@@ -510,8 +510,32 @@ WindowId WaylandInterface::winIdFor(QString appId, QRect geometry) const
 
 bool WaylandInterface::windowCanBeDragged(WindowId wid) const
 {
-    WindowInfoWrap winfo = requestInfo(wid);
-    return (winfo.isValid() && !winfo.isMinimized() && !winfo.isPlasmaDesktop());
+    auto w = windowFor(wid);
+
+    if (w && isValidWindow(w)) {
+        WindowInfoWrap winfo = requestInfo(wid);
+        return (winfo.isValid()
+                && w->isMovable()
+                && !winfo.isMinimized()
+                && !winfo.isPlasmaDesktop());
+    }
+
+    return false;
+}
+
+bool WaylandInterface::windowCanBeMaximized(WindowId wid) const
+{
+    auto w = windowFor(wid);
+
+    if (w && isValidWindow(w)) {
+        WindowInfoWrap winfo = requestInfo(wid);
+        return (winfo.isValid()
+                && w->isMaximizeable()
+                && !winfo.isMinimized()
+                && !winfo.isPlasmaDesktop());
+    }
+
+    return false;
 }
 
 void WaylandInterface::releaseMouseEventFor(WindowId wid) const
@@ -595,7 +619,7 @@ void WaylandInterface::requestToggleMaximized(WindowId wid) const
 {
     auto w = windowFor(wid);
 
-    if (w && isValidWindow(w)) {
+    if (w && isValidWindow(w) && windowCanBeMaximized(wid)) {
 #if KF5_VERSION_MINOR >= 52
         if (!m_currentDesktop.isEmpty()) {
             w->requestEnterVirtualDesktop(m_currentDesktop);
